Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(55)

Unified Diff: content/renderer/media/user_media_client_impl.h

Issue 1834323002: MediaStream audio: Refactor 3 separate "glue" implementations into one. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: REBASE + Workaround to ensure MediaStreamAudioProcessor is destroyed on the main thread. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/media/tagged_list.h ('k') | content/renderer/media/user_media_client_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/media/user_media_client_impl.h
diff --git a/content/renderer/media/user_media_client_impl.h b/content/renderer/media/user_media_client_impl.h
index d4cfb25f00afbbd60cf845906b870dda270cb254..f920ca7420d40b624d3d0edbc3d94a20d60dc0bc 100644
--- a/content/renderer/media/user_media_client_impl.h
+++ b/content/renderer/media/user_media_client_impl.h
@@ -31,6 +31,7 @@
namespace content {
class PeerConnectionDependencyFactory;
+class MediaStreamAudioSource;
class MediaStreamDispatcher;
class MediaStreamVideoSource;
class VideoCapturerDelegate;
@@ -119,8 +120,12 @@ class CONTENT_EXPORT UserMediaClientImpl
virtual void EnumerateSourcesSucceded(
blink::WebMediaStreamTrackSourcesRequest* request,
blink::WebVector<blink::WebSourceInfo>& sources);
- // Creates a MediaStreamVideoSource object.
- // This is virtual for test purposes.
+
+ // Creates a MediaStreamAudioSource/MediaStreamVideoSource objects.
+ // These are virtual for test purposes.
+ virtual MediaStreamAudioSource* CreateAudioSource(
+ const StreamDeviceInfo& device,
+ const blink::WebMediaConstraints& constraints);
virtual MediaStreamVideoSource* CreateVideoSource(
const StreamDeviceInfo& device,
const MediaStreamSource::SourceStoppedCallback& stop_callback);
@@ -147,8 +152,7 @@ class CONTENT_EXPORT UserMediaClientImpl
blink::WebMediaStream web_stream;
blink::WebUserMediaRequest request;
- void StartAudioTrack(const blink::WebMediaStreamTrack& track,
- const blink::WebMediaConstraints& constraints);
+ void StartAudioTrack(const blink::WebMediaStreamTrack& track);
blink::WebMediaStreamTrack CreateAndStartVideoTrack(
const blink::WebMediaStreamSource& source,
« no previous file with comments | « content/renderer/media/tagged_list.h ('k') | content/renderer/media/user_media_client_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698